%global __provides_exclude_from %{_libdir}/opendbx/.*\\.so

%define major	1
%define libname	%mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%bcond_with sqlite2

Name:           opendbx
Version:        1.4.6
Release:        %mkrel 13
Group:          Development/Databases
Summary:        Lightweight but extensible database access library written in C

#License:        LGPLv2+
# (util/argmap.{cpp,hpp}) have a GPL license header rather than an LGPL one
# until upstream decides about this I am leaving GPLv2+ here as the stricter license
License:        GPLv2+
URL:            https://www.linuxnetworks.de/doc/index.php/OpenDBX
Source0:        https://linuxnetworks.de/opendbx/download/%{name}-%{version}.tar.gz
Patch0:         opendbx-1.4.6-freetds-fix.patch
Patch1:		opendbx-1.4.6-doxyfile-fix.patch
Patch2:		opendbx-1.4.6-doxyfile-fix2.patch
Patch3:		opendbx-1.4.6-dtd-reference.patch
Patch4:		0001-Build-unversioned-backend-modules.patch
Patch5:		opendbx-c99.patch
Patch6:		opendbx-fix-build-with-gcc14.patch
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel
%if %{with sqlite2}
BuildRequires:  pkgconfig(sqlite)
%endif
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(fbclient)
BuildRequires:  pkgconfig(readline)
BuildRequires:  freetds-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  doxygen
BuildRequires:  docbook2x
BuildRequires:  docbook-dtds
BuildRequires:  gettext
# needed because of autoreconf usage
BuildRequires:  gettext-devel
# probably a missing dependency in docbook
BuildRequires:  perl(XML::SAX::Expat)

%description
Provides an abstraction layer to all supported databases with a single, clean
and simple interface that leads to an elegant code design automatically.
If you want your application to support different databases with little effort,
this is definitively the right thing for you!

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Requires:	%{name}-common >= %{version}-%{release}
Conflicts:	opendbx < 1.4.6-5

%description -n %{libname}
Shared libraries for %{name}.

%package common
Summary:	Common files for %{name}
Group:		System/Libraries
BuildArch:	noarch
Obsoletes:	opendbx < 1.4.6-5
%if !%{with sqlite2}
Obsoletes:	opendbx-sqlite < %{version}-%{release}
%endif

%description common
Common files for %{name}.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 1.4.6-5

%description -n %{devname}
Development files and headers for %{name}.

%package        mysql
Summary:        MySQL backend - provides mysql support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    mysql
Allows odbx_init with "mysql" as the backend parameter.

%package        postgresql
Summary:        PostgreSQL backend - provides postgresql support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    postgresql
Allows odbx_init with "pgsql" as the backend parameter.

%if %{with sqlite2}
%package        sqlite
Summary:        SQLite 2 backend - provides sqlite2 support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    sqlite
Allows odbx_init with "sqlite" as the backend parameter.
%endif

%package        sqlite3
Summary:        SQLite 3 backend - provides sqlite3 support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    sqlite3
Allows odbx_init with "sqlite3" as the backend parameter.

%package        firebird
Summary:        Firebird backend - provides firebird support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    firebird
Allows odbx_init with "firebird" as the backend parameter.

%package        sybase
Summary:        Sybase backend - provides sybase support in %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}

%description    sybase
Allows odbx_init with "sybase" as the backend parameter.

%package        utils
Summary:        Utility binaries for %{name}
Group:          Development/Databases

%description    utils
The %{name}-utils package provides the odbx-sql tool.

%prep
%autosetup -p1

# To fix Doxygen parsing issue
ln -s api lib/%{name}/api.dox

# Update Doxygen files
doxygen -u doc/Doxyfile.in

%build
autoreconf -f -i
export CPPFLAGS="-I%{_includedir}/mysql"
export CXXFLAGS="%{build_cxxflags} -std=c++14"
%configure \
%if %{with sqlite2}
    --with-backends="mysql pgsql sqlite sqlite3 firebird sybase" \
%else
    --with-backends="mysql pgsql sqlite3 firebird sybase" \
%endif
    --disable-test \
    --disable-static

%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

%find_lang %{name}
%find_lang %{name}-utils

%files common -f %{name}.lang
%dir %{_datadir}/opendbx/
%{_datadir}/opendbx/keywords

%files -n %{libname}
%doc AUTHORS COPYING ChangeLog NEWS README
%dir %{_libdir}/opendbx/
%{_libdir}/lib%{name}*.so.%{major}
%{_libdir}/lib%{name}*.so.%{major}.*

%files -n %{devname}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3*

%files mysql
%{_libdir}/opendbx/*mysql*.so

%files postgresql
%{_libdir}/opendbx/*pgsql*.so

%if %{with sqlite2}
%files sqlite
%{_libdir}/opendbx/*sqlitebackend.so
%endif

%files sqlite3
%{_libdir}/opendbx/*sqlite3backend.so

%files firebird
%{_libdir}/opendbx/*firebird*.so

%files sybase
%{_libdir}/opendbx/*sybase*.so

%files utils -f %{name}-utils.lang
%{_bindir}/odbx-sql
%{_mandir}/man1/odbx-sql.1*


%changelog
* Thu Nov 21 2024 ns80 <ns80> 1.4.6-13.mga10
+ Revision: 2118024
- add another patch to try to fix building with GCC 14
- add a patch from Fedora to try to fix building with GCC 14

* Fri Jun 16 2023 daviddavid <daviddavid> 1.4.6-12.mga9
+ Revision: 1962125
- drop sqlite2 support (mga#32018)

* Fri Oct 28 2022 danf <danf> 1.4.6-11.mga9
+ Revision: 1899906
- Compile as C++14 to fix dynamic exception error
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Jan 26 2021 wally <wally> 1.4.6-10.mga8
+ Revision: 1673576
- add patch to fix build with new doxygen

* Wed Feb 19 2020 umeabot <umeabot> 1.4.6-9.mga8
+ Revision: 1542728
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 06 2020 luigiwalser <luigiwalser> 1.4.6-8.mga8
+ Revision: 1476814
- rebuild for readline

* Sun Sep 23 2018 umeabot <umeabot> 1.4.6-7.mga7
+ Revision: 1300008
- Mageia 7 Mass Rebuild

* Thu Dec 21 2017 guillomovitch <guillomovitch> 1.4.6-6.mga7
+ Revision: 1183663
- rebuild to fix mariadb dependency

* Tue Jan 10 2017 wally <wally> 1.4.6-5.mga6
+ Revision: 1080929
- fix libification
- add patch to build unversioned backend modules

* Mon Jan 09 2017 luigiwalser <luigiwalser> 1.4.6-4.mga6
+ Revision: 1080783
- use local docbookx.dtd during build

* Mon Apr 11 2016 philippem <philippem> 1.4.6-3.mga6
+ Revision: 1000302
- change br for firebird3

* Fri Feb 26 2016 luigiwalser <luigiwalser> 1.4.6-2.mga6
+ Revision: 979744
- rebuild with configure2_5x

* Sun Dec 13 2015 guillomovitch <guillomovitch> 1.4.6-1.mga6
+ Revision: 910221
- imported package opendbx

